@@ -31,7 +31,12 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
                 "Validate Azure Pipelines config against the schema provided "
                 "by Microsoft"
             ),
-            "add_args": ["--data-transform", "azure-pipelines"],
+            "add_args": [
+                "--data-transform",
+                "azure-pipelines",
+                "--regex-variant",
+                "nonunicode",
+            ],
             "files": r"^(\.)?azure-pipelines\.(yml|yaml)$",
             "types": "yaml",
         },
@@ -93,6 +98,22 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
             "types_or": ["json", "yaml"],
         },
     },
+    "compose-spec": {
+        "url": _githubusercontent_url(
+            "compose-spec",
+            "compose-spec",
+            "master",
+            "schema/compose-spec.json",
+        ),
+        "hook_config": {
+            "name": "Validate Docker Compose files",
+            "files": [
+                r"([^/]*/)*docker-compose(\.[\.a-zA-Z0-9_-]*)*\.(yml|yaml)",
+                r"([^/]*/)*compose(\.[\.a-zA-Z0-9_-]*)*\.(yml|yaml)",
+            ],
+            "types": "yaml",
+        },
+    },
     "dependabot": {
         "url": "https://json.schemastore.org/dependabot-2.0.json",
         "hook_config": {
@@ -135,11 +156,36 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
         ),
         "hook_config": {
             "name": "Validate GitLab CI config",
-            "add_args": ["--data-transform", "gitlab-ci"],
+            "add_args": [
+                "--data-transform",
+                "gitlab-ci",
+                "--regex-variant",
+                "nonunicode",
+            ],
             "files": r"^.*\.gitlab-ci\.yml$",
             "types": "yaml",
         },
     },
+    "meltano": {
+        "url": _githubusercontent_url(
+            "meltano",
+            "meltano",
+            "main",
+            "src/meltano/schemas/meltano.schema.json",
+        ),
+        "hook_config": {
+            "name": "Validate Meltano Config",
+            "description": (
+                "Validate Meltano config against the schema provided by Meltano"
+            ),
+            "files": [
+                r".*meltano\.yml",
+                r"meltano-manifest\.json",
+                r"meltano-manifest\..+\.json",
+            ],
+            "types_or": ["json", "yaml"],
+        },
+    },
     "mergify": {
         "url": "https://docs.mergify.com/mergify-configuration-schema.json",
         "hook_config": {
@@ -156,7 +202,7 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
         "url": _githubusercontent_url(
             "readthedocs",
             "readthedocs.org",
-            "master",
+            "main",
             "readthedocs/rtd_tests/fixtures/spec/v2/schema.json",
         ),
         "hook_config": {
@@ -177,6 +223,7 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
                 "Validate Renovate config against the schema provided by "
                 "Renovate (does not support renovate config in package.json)"
             ),
+            "add_args": ["--regex-variant", "nonunicode"],
             "files": [
                 r"renovate\.(json|json5)",
                 r"\.(github|gitlab)/renovate\.(json|json5)",
@@ -185,6 +232,19 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
             ],
         },
     },
+    "snapcraft": {
+        "url": _githubusercontent_url(
+            "canonical", "snapcraft", "main", "schema/snapcraft.json"
+        ),
+        "hook_config": {
+            "name": "Validate snapcraft files",
+            "description": (
+                "Validate snapcraft files against the schema provided by Canonical"
+            ),
+            "files": r"^(.+/)?snapcraft\.yaml$",
+            "types": "yaml",
+        },
+    },
     "taskfile": {
         "url": "https://taskfile.dev/schema.json",
         "hook_config": {
